@@ -1,3 +1,21 @@
+// Copyright (C) 2009 Novell, Inc.
+// Copyright (C) 2009 Julien Rebetez
+// Copyright (C) 2009 Łukasz Jernaś
+// Copyright (C) 2009 Andreu Correa Casablanca
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either version 2
+// of the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 using System;
 using System.IO;
@@ -81,7 +99,8 @@ namespace PdfMod.Gui
             AddImportant (
                 new ToggleActionEntry ("Properties", Stock.Properties, null, "<alt>Return", Catalog.GetString ("View and edit the title, keywords, and more for this document"), OnProperties, false),
                 new ToggleActionEntry ("ZoomFit", Stock.ZoomFit, null, "<control>0", null, OnZoomFit, true),
-                new ToggleActionEntry ("ViewToolbar", null, Catalog.GetString ("Toolbar"), null, null, OnViewToolbar, Client.Configuration.ShowToolbar)
+                new ToggleActionEntry ("ViewToolbar", null, Catalog.GetString ("Toolbar"), null, null, OnViewToolbar, Client.Configuration.ShowToolbar),
+                new ToggleActionEntry ("FullScreenView", null, Catalog.GetString ("Fullscreen"), "F11", null, OnFullScreenView, false)
             );
 
             this["RotateRight"].IconName = "object-rotate-right";
@@ -210,6 +229,17 @@ namespace PdfMod.Gui
             System.Diagnostics.Process.Start (app.Document.CurrentStateUri);
         }
 
+        private void OnFullScreenView (object o, EventArgs args)
+        {
+            bool fullscreen = (this["FullScreenView"] as ToggleAction).Active;
+
+            if (fullscreen) {
+                app.Window.Fullscreen ();
+            } else {
+                app.Window.Unfullscreen ();
+            }
+        }
+
         private void OnInsertFrom (object o, EventArgs args)
         {
             var chooser = new Gtk.FileChooserDialog (Catalog.GetString ("Select PDF"), app.Window, FileChooserAction.Open);
@@ -414,7 +444,10 @@ namespace PdfMod.Gui
                     "\tIgor Vatavuk",
                     "\tBertrand Lorentz",
                     "\tMichael McKinley",
-                    "\tŁukasz Jernaś"
+                    "\tŁukasz Jernaś",
+                    "\tRomain Tartière",
+                    "\tRobert Dyer",
+                    "\tAndreu Correa Casablanca"
                 },
                 Documenters = new string [] { "Gabriel Burt" },
                 Artists = new string [] { "Kalle Persson" },
